@@ -1,6 +1,6 @@
-from .app import App, Binding, Parser, SubParser, SubParsers
 from .choices import Choices
 from .param import Param, param
+from .parser import Binding, Parser, SubParser, SubParsers
 from .typed_argparse import (
     TypedArgs,
     WithUnionType,
@@ -9,7 +9,7 @@ from .typed_argparse import (
     validate_type_union,
 )
 
-VERSION = "0.2.1"
+VERSION = "0.2.2"
 
 __all__ = [
     "Choices",
@@ -18,7 +18,6 @@ __all__ = [
     "get_choices_from",
     "get_choices_from_class",
     "validate_type_union",
-    "App",
     "Parser",
     "SubParser",
     "SubParsers",
